<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="309"/>
        <source>Crash Report</source>
        <translation>Strigties ataskaita</translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="310"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; užstrigo pernelyg daug kartų. Programos automatinis paleidimas iš naujo yra išjungtas iki kito prisijungimo.</translation>
    </message>
</context>
<context>
    <name>SessionApplication</name>
    <message>
        <location filename="../../../src/main.cpp" line="58"/>
        <source>Configuration file path.</source>
        <translation>Konfigūracijos failo kelias.</translation>
    </message>
    <message>
        <location filename="../../../src/main.cpp" line="58"/>
        <location filename="../../../src/main.cpp" line="59"/>
        <source>file</source>
        <translation>failas</translation>
    </message>
    <message>
        <location filename="../../../src/main.cpp" line="59"/>
        <source>Window manager to use.</source>
        <translation>Langų tvarkytuvė, kurią naudoti.</translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Sveiki atvykę į LXQt</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Sveiki atvykę į LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Prašome pasirinkti savo numatytąją langų tvarkytuvę.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation>Jūs tai galėsite pakeisti bet kuriuo metu per Nuostatos -&gt; Seanso nustatymai -&gt; Pagrindiniai nustatymai.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation>Kita ...</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation>Pasirinkite savo mėgstamą.</translation>
    </message>
</context>
</TS>
